# Generated by h2py from /opt/mqm/inc/cmqxc.h

from struct import calcsize

# 64bit
if calcsize("P") == 8:
    MQACH_CURRENT_LENGTH = 72
    MQCD_LENGTH_4 = 1568
    MQCD_LENGTH_5 = 1584
    MQCD_LENGTH_6 = 1688
    MQCD_LENGTH_7 = 1792
    MQCD_LENGTH_8 = 1888
    MQCD_LENGTH_9 = 1912
    MQCD_CURRENT_LENGTH = 1912
else:
    MQACH_CURRENT_LENGTH = 68
    MQCD_LENGTH_4 = 1540
    MQCD_LENGTH_5 = 1552
    MQCD_LENGTH_6 = 1648
    MQCD_LENGTH_7 = 1748
    MQCD_LENGTH_8 = 1840
    MQCD_LENGTH_9 = 1864
    MQCD_CURRENT_LENGTH = 1864

MQACH_STRUC_ID = "ACH "
MQACH_VERSION_1 = 1
MQACH_CURRENT_VERSION = 1
MQACH_LENGTH_1 = 72
MQACH_CURRENT_LENGTH = 72
MQACH_LENGTH_1 = 68
MQACH_CURRENT_LENGTH = 68
MQAXC_STRUC_ID = "AXC "
MQAXC_VERSION_1 = 1
MQAXC_CURRENT_VERSION = 1
MQXE_OTHER = 0
MQXE_MCA = 1
MQXE_MCA_SVRCONN = 2
MQXE_COMMAND_SERVER = 3
MQXE_MQSC = 4
MQAXP_STRUC_ID = "AXP "
MQAXP_VERSION_1 = 1
MQAXP_VERSION_2 = 2
MQAXP_CURRENT_VERSION = 2
MQXACT_EXTERNAL = 1
MQXACT_INTERNAL = 2
MQXPDA_NONE = "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"\
                     "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"\
                     "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
MQXF_INIT = 1
MQXF_TERM = 2
MQXF_CONN = 3
MQXF_CONNX = 4
MQXF_DISC = 5
MQXF_OPEN = 6
MQXF_CLOSE = 7
MQXF_PUT1 = 8
MQXF_PUT = 9
MQXF_GET = 10
MQXF_DATA_CONV_ON_GET = 11
MQXF_INQ = 12
MQXF_SET = 13
MQXF_BEGIN = 14
MQXF_CMIT = 15
MQXF_BACK = 16
MQXF_STAT = 18
MQXF_CB = 19
MQXF_CTL = 20
MQXF_CALLBACK = 21
MQXF_SUB = 22
MQXF_SUBRQ = 23
MQCD_VERSION_1 = 1
MQCD_VERSION_2 = 2
MQCD_VERSION_3 = 3
MQCD_VERSION_4 = 4
MQCD_VERSION_5 = 5
MQCD_VERSION_6 = 6
MQCD_VERSION_7 = 7
MQCD_VERSION_8 = 8
MQCD_VERSION_9 = 9
MQCD_CURRENT_VERSION = 9
MQCHT_SENDER = 1
MQCHT_SERVER = 2
MQCHT_RECEIVER = 3
MQCHT_REQUESTER = 4
MQCHT_ALL = 5
MQCHT_CLNTCONN = 6
MQCHT_SVRCONN = 7
MQCHT_CLUSRCVR = 8
MQCHT_CLUSSDR = 9
MQCOMPRESS_NOT_AVAILABLE = (-1)
MQCOMPRESS_NONE = 0
MQCOMPRESS_RLE = 1
MQCOMPRESS_ZLIBFAST = 2
MQCOMPRESS_ZLIBHIGH = 4
MQCOMPRESS_SYSTEM = 8
MQCOMPRESS_ANY = 0x0FFFFFFF
MQXPT_ALL = (-1)
MQXPT_LOCAL = 0
MQXPT_LU62 = 1
MQXPT_TCP = 2
MQXPT_NETBIOS = 3
MQXPT_SPX = 4
MQXPT_DECNET = 5
MQXPT_UDP = 6
MQPA_DEFAULT = 1
MQPA_CONTEXT = 2
MQPA_ONLY_MCA = 3
MQPA_ALTERNATE_OR_MCA = 4
MQCDC_SENDER_CONVERSION = 1
MQCDC_NO_SENDER_CONVERSION = 0
MQMCAT_PROCESS = 1
MQMCAT_THREAD = 2
MQNPMS_NORMAL = 1
MQNPMS_FAST = 2
MQSCA_REQUIRED = 0
MQSCA_OPTIONAL = 1
MQKAI_AUTO = (-1)
MQCAFTY_NONE = 0
MQCAFTY_PREFERRED = 1
MQCXP_STRUC_ID = "CXP "
MQCXP_VERSION_1 = 1
MQCXP_VERSION_2 = 2
MQCXP_VERSION_3 = 3
MQCXP_VERSION_4 = 4
MQCXP_VERSION_5 = 5
MQCXP_VERSION_6 = 6
MQCXP_VERSION_7 = 7
MQCXP_CURRENT_VERSION = 7
MQXR2_PUT_WITH_DEF_ACTION = 0
MQXR2_PUT_WITH_DEF_USERID = 1
MQXR2_PUT_WITH_MSG_USERID = 2
MQXR2_USE_AGENT_BUFFER = 0
MQXR2_USE_EXIT_BUFFER = 4
MQXR2_DEFAULT_CONTINUATION = 0
MQXR2_CONTINUE_CHAIN = 8
MQXR2_SUPPRESS_CHAIN = 16
MQXR2_STATIC_CACHE = 0
MQXR2_DYNAMIC_CACHE = 32
MQCF_NONE = 0x00000000
MQCF_DIST_LISTS = 0x00000001
MQDXP_STRUC_ID = "DXP "
MQDXP_VERSION_1 = 1
MQDXP_CURRENT_VERSION = 1
MQXDR_OK = 0
MQXDR_CONVERSION_FAILED = 1
MQPXP_STRUC_ID = "PXP "
MQPXP_VERSION_1 = 1
MQPXP_CURRENT_VERSION = 1
MQDT_APPL = 1
MQDT_BROKER = 2
MQTXP_STRUC_ID = "TXP "
MQTXP_VERSION_1 = 1
MQTXP_CURRENT_VERSION = 1
MQWDR_STRUC_ID = "WDR "
MQWDR_VERSION_1 = 1
MQWDR_VERSION_2 = 2
MQWDR_CURRENT_VERSION = 2
MQWDR_LENGTH_1 = 124
MQWDR_LENGTH_2 = 136
MQWDR_CURRENT_LENGTH = 136
MQQMF_REPOSITORY_Q_MGR = 0x00000002
MQQMF_CLUSSDR_USER_DEFINED = 0x00000008
MQQMF_CLUSSDR_AUTO_DEFINED = 0x00000010
MQQMF_AVAILABLE = 0x00000020
MQWQR_STRUC_ID = "WQR "
MQWQR_VERSION_1 = 1
MQWQR_VERSION_2 = 2
MQWQR_VERSION_3 = 3
MQWQR_CURRENT_VERSION = 3
MQWQR_LENGTH_1 = 200
MQWQR_LENGTH_2 = 208
MQWQR_LENGTH_3 = 212
MQWQR_CURRENT_LENGTH = 212
MQQF_LOCAL_Q = 0x00000001
MQQF_CLWL_USEQ_ANY = 0x00000040
MQQF_CLWL_USEQ_LOCAL = 0x00000080
MQWXP_STRUC_ID = "WXP "
MQWXP_VERSION_1 = 1
MQWXP_VERSION_2 = 2
MQWXP_VERSION_3 = 3
MQWXP_CURRENT_VERSION = 3
MQWXP_PUT_BY_CLUSTER_CHL = 0x00000002
MQCLCT_STATIC = 0
MQCLCT_DYNAMIC = 1
MQXEPO_STRUC_ID = "XEPO"
MQXEPO_VERSION_1 = 1
MQXEPO_CURRENT_VERSION = 1
MQXEPO_NONE = 0x00000000
MQXT_API_CROSSING_EXIT = 1
MQXT_API_EXIT = 2
MQXT_CHANNEL_SEC_EXIT = 11
MQXT_CHANNEL_MSG_EXIT = 12
MQXT_CHANNEL_SEND_EXIT = 13
MQXT_CHANNEL_RCV_EXIT = 14
MQXT_CHANNEL_MSG_RETRY_EXIT = 15
MQXT_CHANNEL_AUTO_DEF_EXIT = 16
MQXT_CLUSTER_WORKLOAD_EXIT = 20
MQXT_PUBSUB_ROUTING_EXIT = 21
MQXR_BEFORE = 1
MQXR_AFTER = 2
MQXR_CONNECTION = 3
MQXR_INIT = 11
MQXR_TERM = 12
MQXR_MSG = 13
MQXR_XMIT = 14
MQXR_SEC_MSG = 15
MQXR_INIT_SEC = 16
MQXR_RETRY = 17
MQXR_AUTO_CLUSSDR = 18
MQXR_AUTO_RECEIVER = 19
MQXR_CLWL_OPEN = 20
MQXR_CLWL_PUT = 21
MQXR_CLWL_MOVE = 22
MQXR_CLWL_REPOS = 23
MQXR_CLWL_REPOS_MOVE = 24
MQXR_END_BATCH = 25
MQXR_ACK_RECEIVED = 26
MQXR_AUTO_SVRCONN = 27
MQXR_AUTO_CLUSRCVR = 28
MQXR_SEC_PARMS = 29
MQXCC_OK = 0
MQXCC_SUPPRESS_FUNCTION = (-1)
MQXCC_SKIP_FUNCTION = (-2)
MQXCC_SEND_AND_REQUEST_SEC_MSG = (-3)
MQXCC_SEND_SEC_MSG = (-4)
MQXCC_SUPPRESS_EXIT = (-5)
MQXCC_CLOSE_CHANNEL = (-6)
MQXCC_REQUEST_ACK = (-7)
MQXCC_FAILED = (-8)
MQXUA_NONE = "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
MQDCC_DEFAULT_CONVERSION = 0x00000001
MQDCC_FILL_TARGET_BUFFER = 0x00000002
MQDCC_INT_DEFAULT_CONVERSION = 0x00000004
MQDCC_SOURCE_ENC_NATIVE = 0x00000020
MQDCC_SOURCE_ENC_NORMAL = 0x00000010
MQDCC_SOURCE_ENC_REVERSED = 0x00000020
MQDCC_SOURCE_ENC_UNDEFINED = 0x00000000
MQDCC_TARGET_ENC_NATIVE = 0x00000200
MQDCC_TARGET_ENC_NORMAL = 0x00000100
MQDCC_TARGET_ENC_REVERSED = 0x00000200
MQDCC_TARGET_ENC_UNDEFINED = 0x00000000
MQDCC_NONE = 0x00000000
MQDCC_SOURCE_ENC_MASK = 0x000000F0
MQDCC_TARGET_ENC_MASK = 0x00000F00
MQDCC_SOURCE_ENC_FACTOR = 16
MQDCC_TARGET_ENC_FACTOR = 256

# Manually added
MQCXP_STRUC_ID_ARRAY = ['C','X','P',' ']
MQDXP_STRUC_ID_ARRAY = ['D','X','P',' ']
MQPXP_STRUC_ID_ARRAY = ['P','X','P',' ']
MQWDR_STRUC_ID_ARRAY = ['W','D','R',' ']
MQWQR_STRUC_ID_ARRAY = ['W','Q','R',' ']
MQWXP_STRUC_ID_ARRAY = ['W','X','P',' ']
MQXUA_NONE_ARRAY = ['\0','\0','\0','\0','\0','\0','\0','\0', '\0','\0','\0','\0','\0','\0','\0','\0']



# Generated by h2py from /opt/mqm/inc/cmqcfc.h
MQCFH_STRUC_LENGTH = 36
MQCFH_VERSION_1 = 1
MQCFH_VERSION_2 = 2
MQCFH_VERSION_3 = 3
MQCFH_CURRENT_VERSION = 3
MQCMD_NONE = 0
MQCMD_CHANGE_Q_MGR = 1
MQCMD_INQUIRE_Q_MGR = 2
MQCMD_CHANGE_PROCESS = 3
MQCMD_COPY_PROCESS = 4
MQCMD_CREATE_PROCESS = 5
MQCMD_DELETE_PROCESS = 6
MQCMD_INQUIRE_PROCESS = 7
MQCMD_CHANGE_Q = 8
MQCMD_CLEAR_Q = 9
MQCMD_COPY_Q = 10
MQCMD_CREATE_Q = 11
MQCMD_DELETE_Q = 12
MQCMD_INQUIRE_Q = 13
MQCMD_REFRESH_Q_MGR = 16
MQCMD_RESET_Q_STATS = 17
MQCMD_INQUIRE_Q_NAMES = 18
MQCMD_INQUIRE_PROCESS_NAMES = 19
MQCMD_INQUIRE_CHANNEL_NAMES = 20
MQCMD_CHANGE_CHANNEL = 21
MQCMD_COPY_CHANNEL = 22
MQCMD_CREATE_CHANNEL = 23
MQCMD_DELETE_CHANNEL = 24
MQCMD_INQUIRE_CHANNEL = 25
MQCMD_PING_CHANNEL = 26
MQCMD_RESET_CHANNEL = 27
MQCMD_START_CHANNEL = 28
MQCMD_STOP_CHANNEL = 29
MQCMD_START_CHANNEL_INIT = 30
MQCMD_START_CHANNEL_LISTENER = 31
MQCMD_CHANGE_NAMELIST = 32
MQCMD_COPY_NAMELIST = 33
MQCMD_CREATE_NAMELIST = 34
MQCMD_DELETE_NAMELIST = 35
MQCMD_INQUIRE_NAMELIST = 36
MQCMD_INQUIRE_NAMELIST_NAMES = 37
MQCMD_ESCAPE = 38
MQCMD_RESOLVE_CHANNEL = 39
MQCMD_PING_Q_MGR = 40
MQCMD_INQUIRE_Q_STATUS = 41
MQCMD_INQUIRE_CHANNEL_STATUS = 42
MQCMD_CONFIG_EVENT = 43
MQCMD_Q_MGR_EVENT = 44
MQCMD_PERFM_EVENT = 45
MQCMD_CHANNEL_EVENT = 46
MQCMD_DELETE_PUBLICATION = 60
MQCMD_DEREGISTER_PUBLISHER = 61
MQCMD_DEREGISTER_SUBSCRIBER = 62
MQCMD_PUBLISH = 63
MQCMD_REGISTER_PUBLISHER = 64
MQCMD_REGISTER_SUBSCRIBER = 65
MQCMD_REQUEST_UPDATE = 66
MQCMD_BROKER_INTERNAL = 67
MQCMD_ACTIVITY_MSG = 69
MQCMD_INQUIRE_CLUSTER_Q_MGR = 70
MQCMD_RESUME_Q_MGR_CLUSTER = 71
MQCMD_SUSPEND_Q_MGR_CLUSTER = 72
MQCMD_REFRESH_CLUSTER = 73
MQCMD_RESET_CLUSTER = 74
MQCMD_TRACE_ROUTE = 75
MQCMD_REFRESH_SECURITY = 78
MQCMD_CHANGE_AUTH_INFO = 79
MQCMD_COPY_AUTH_INFO = 80
MQCMD_CREATE_AUTH_INFO = 81
MQCMD_DELETE_AUTH_INFO = 82
MQCMD_INQUIRE_AUTH_INFO = 83
MQCMD_INQUIRE_AUTH_INFO_NAMES = 84
MQCMD_INQUIRE_CONNECTION = 85
MQCMD_STOP_CONNECTION = 86
MQCMD_INQUIRE_AUTH_RECS = 87
MQCMD_INQUIRE_ENTITY_AUTH = 88
MQCMD_DELETE_AUTH_REC = 89
MQCMD_SET_AUTH_REC = 90
MQCMD_LOGGER_EVENT = 91
MQCMD_RESET_Q_MGR = 92
MQCMD_CHANGE_LISTENER = 93
MQCMD_COPY_LISTENER = 94
MQCMD_CREATE_LISTENER = 95
MQCMD_DELETE_LISTENER = 96
MQCMD_INQUIRE_LISTENER = 97
MQCMD_INQUIRE_LISTENER_STATUS = 98
MQCMD_COMMAND_EVENT = 99
MQCMD_CHANGE_SECURITY = 100
MQCMD_CHANGE_CF_STRUC = 101
MQCMD_CHANGE_STG_CLASS = 102
MQCMD_CHANGE_TRACE = 103
MQCMD_ARCHIVE_LOG = 104
MQCMD_BACKUP_CF_STRUC = 105
MQCMD_CREATE_BUFFER_POOL = 106
MQCMD_CREATE_PAGE_SET = 107
MQCMD_CREATE_CF_STRUC = 108
MQCMD_CREATE_STG_CLASS = 109
MQCMD_COPY_CF_STRUC = 110
MQCMD_COPY_STG_CLASS = 111
MQCMD_DELETE_CF_STRUC = 112
MQCMD_DELETE_STG_CLASS = 113
MQCMD_INQUIRE_ARCHIVE = 114
MQCMD_INQUIRE_CF_STRUC = 115
MQCMD_INQUIRE_CF_STRUC_STATUS = 116
MQCMD_INQUIRE_CMD_SERVER = 117
MQCMD_INQUIRE_CHANNEL_INIT = 118
MQCMD_INQUIRE_QSG = 119
MQCMD_INQUIRE_LOG = 120
MQCMD_INQUIRE_SECURITY = 121
MQCMD_INQUIRE_STG_CLASS = 122
MQCMD_INQUIRE_SYSTEM = 123
MQCMD_INQUIRE_THREAD = 124
MQCMD_INQUIRE_TRACE = 125
MQCMD_INQUIRE_USAGE = 126
MQCMD_MOVE_Q = 127
MQCMD_RECOVER_BSDS = 128
MQCMD_RECOVER_CF_STRUC = 129
MQCMD_RESET_TPIPE = 130
MQCMD_RESOLVE_INDOUBT = 131
MQCMD_RESUME_Q_MGR = 132
MQCMD_REVERIFY_SECURITY = 133
MQCMD_SET_ARCHIVE = 134
MQCMD_SET_LOG = 136
MQCMD_SET_SYSTEM = 137
MQCMD_START_CMD_SERVER = 138
MQCMD_START_Q_MGR = 139
MQCMD_START_TRACE = 140
MQCMD_STOP_CHANNEL_INIT = 141
MQCMD_STOP_CHANNEL_LISTENER = 142
MQCMD_STOP_CMD_SERVER = 143
MQCMD_STOP_Q_MGR = 144
MQCMD_STOP_TRACE = 145
MQCMD_SUSPEND_Q_MGR = 146
MQCMD_INQUIRE_CF_STRUC_NAMES = 147
MQCMD_INQUIRE_STG_CLASS_NAMES = 148
MQCMD_CHANGE_SERVICE = 149
MQCMD_COPY_SERVICE = 150
MQCMD_CREATE_SERVICE = 151
MQCMD_DELETE_SERVICE = 152
MQCMD_INQUIRE_SERVICE = 153
MQCMD_INQUIRE_SERVICE_STATUS = 154
MQCMD_START_SERVICE = 155
MQCMD_STOP_SERVICE = 156
MQCMD_DELETE_BUFFER_POOL = 157
MQCMD_DELETE_PAGE_SET = 158
MQCMD_CHANGE_BUFFER_POOL = 159
MQCMD_CHANGE_PAGE_SET = 160
MQCMD_INQUIRE_Q_MGR_STATUS = 161
MQCMD_CREATE_LOG = 162
MQCMD_STATISTICS_MQI = 164
MQCMD_STATISTICS_Q = 165
MQCMD_STATISTICS_CHANNEL = 166
MQCMD_ACCOUNTING_MQI = 167
MQCMD_ACCOUNTING_Q = 168
MQCMD_INQUIRE_AUTH_SERVICE = 169
MQCMD_CHANGE_TOPIC = 170
MQCMD_COPY_TOPIC = 171
MQCMD_CREATE_TOPIC = 172
MQCMD_DELETE_TOPIC = 173
MQCMD_INQUIRE_TOPIC = 174
MQCMD_INQUIRE_TOPIC_NAMES = 175
MQCMD_INQUIRE_SUBSCRIPTION = 176
MQCMD_CREATE_SUBSCRIPTION = 177
MQCMD_CHANGE_SUBSCRIPTION = 178
MQCMD_DELETE_SUBSCRIPTION = 179
MQCMD_COPY_SUBSCRIPTION = 181
MQCMD_INQUIRE_SUB_STATUS = 182
MQCMD_INQUIRE_TOPIC_STATUS = 183
MQCMD_CLEAR_TOPIC_STRING = 184
MQCMD_INQUIRE_PUBSUB_STATUS = 185
MQCFC_LAST = 1
MQCFC_NOT_LAST = 0
MQRCCF_CFH_TYPE_ERROR = 3001
MQRCCF_CFH_LENGTH_ERROR = 3002
MQRCCF_CFH_VERSION_ERROR = 3003
MQRCCF_CFH_MSG_SEQ_NUMBER_ERR = 3004
MQRCCF_CFH_CONTROL_ERROR = 3005
MQRCCF_CFH_PARM_COUNT_ERROR = 3006
MQRCCF_CFH_COMMAND_ERROR = 3007
MQRCCF_COMMAND_FAILED = 3008
MQRCCF_CFIN_LENGTH_ERROR = 3009
MQRCCF_CFST_LENGTH_ERROR = 3010
MQRCCF_CFST_STRING_LENGTH_ERR = 3011
MQRCCF_FORCE_VALUE_ERROR = 3012
MQRCCF_STRUCTURE_TYPE_ERROR = 3013
MQRCCF_CFIN_PARM_ID_ERROR = 3014
MQRCCF_CFST_PARM_ID_ERROR = 3015
MQRCCF_MSG_LENGTH_ERROR = 3016
MQRCCF_CFIN_DUPLICATE_PARM = 3017
MQRCCF_CFST_DUPLICATE_PARM = 3018
MQRCCF_PARM_COUNT_TOO_SMALL = 3019
MQRCCF_PARM_COUNT_TOO_BIG = 3020
MQRCCF_Q_ALREADY_IN_CELL = 3021
MQRCCF_Q_TYPE_ERROR = 3022
MQRCCF_MD_FORMAT_ERROR = 3023
MQRCCF_CFSL_LENGTH_ERROR = 3024
MQRCCF_REPLACE_VALUE_ERROR = 3025
MQRCCF_CFIL_DUPLICATE_VALUE = 3026
MQRCCF_CFIL_COUNT_ERROR = 3027
MQRCCF_CFIL_LENGTH_ERROR = 3028
MQRCCF_QUIESCE_VALUE_ERROR = 3029
MQRCCF_MODE_VALUE_ERROR = 3029
MQRCCF_MSG_SEQ_NUMBER_ERROR = 3030
MQRCCF_PING_DATA_COUNT_ERROR = 3031
MQRCCF_PING_DATA_COMPARE_ERROR = 3032
MQRCCF_CFSL_PARM_ID_ERROR = 3033
MQRCCF_CHANNEL_TYPE_ERROR = 3034
MQRCCF_PARM_SEQUENCE_ERROR = 3035
MQRCCF_XMIT_PROTOCOL_TYPE_ERR = 3036
MQRCCF_BATCH_SIZE_ERROR = 3037
MQRCCF_DISC_INT_ERROR = 3038
MQRCCF_SHORT_RETRY_ERROR = 3039
MQRCCF_SHORT_TIMER_ERROR = 3040
MQRCCF_LONG_RETRY_ERROR = 3041
MQRCCF_LONG_TIMER_ERROR = 3042
MQRCCF_SEQ_NUMBER_WRAP_ERROR = 3043
MQRCCF_MAX_MSG_LENGTH_ERROR = 3044
MQRCCF_PUT_AUTH_ERROR = 3045
MQRCCF_PURGE_VALUE_ERROR = 3046
MQRCCF_CFIL_PARM_ID_ERROR = 3047
MQRCCF_MSG_TRUNCATED = 3048
MQRCCF_CCSID_ERROR = 3049
MQRCCF_ENCODING_ERROR = 3050
MQRCCF_QUEUES_VALUE_ERROR = 3051
MQRCCF_DATA_CONV_VALUE_ERROR = 3052
MQRCCF_INDOUBT_VALUE_ERROR = 3053
MQRCCF_ESCAPE_TYPE_ERROR = 3054
MQRCCF_REPOS_VALUE_ERROR = 3055
MQRCCF_CHANNEL_TABLE_ERROR = 3062
MQRCCF_MCA_TYPE_ERROR = 3063
MQRCCF_CHL_INST_TYPE_ERROR = 3064
MQRCCF_CHL_STATUS_NOT_FOUND = 3065
MQRCCF_CFSL_DUPLICATE_PARM = 3066
MQRCCF_CFSL_TOTAL_LENGTH_ERROR = 3067
MQRCCF_CFSL_COUNT_ERROR = 3068
MQRCCF_CFSL_STRING_LENGTH_ERR = 3069
MQRCCF_BROKER_DELETED = 3070
MQRCCF_STREAM_ERROR = 3071
MQRCCF_TOPIC_ERROR = 3072
MQRCCF_NOT_REGISTERED = 3073
MQRCCF_Q_MGR_NAME_ERROR = 3074
MQRCCF_INCORRECT_STREAM = 3075
MQRCCF_Q_NAME_ERROR = 3076
MQRCCF_NO_RETAINED_MSG = 3077
MQRCCF_DUPLICATE_IDENTITY = 3078
MQRCCF_INCORRECT_Q = 3079
MQRCCF_CORREL_ID_ERROR = 3080
MQRCCF_NOT_AUTHORIZED = 3081
MQRCCF_UNKNOWN_STREAM = 3082
MQRCCF_REG_OPTIONS_ERROR = 3083
MQRCCF_PUB_OPTIONS_ERROR = 3084
MQRCCF_UNKNOWN_BROKER = 3085
MQRCCF_Q_MGR_CCSID_ERROR = 3086
MQRCCF_DEL_OPTIONS_ERROR = 3087
MQRCCF_CLUSTER_NAME_CONFLICT = 3088
MQRCCF_REPOS_NAME_CONFLICT = 3089
MQRCCF_CLUSTER_Q_USAGE_ERROR = 3090
MQRCCF_ACTION_VALUE_ERROR = 3091
MQRCCF_COMMS_LIBRARY_ERROR = 3092
MQRCCF_NETBIOS_NAME_ERROR = 3093
MQRCCF_BROKER_COMMAND_FAILED = 3094
MQRCCF_CFST_CONFLICTING_PARM = 3095
MQRCCF_PATH_NOT_VALID = 3096
MQRCCF_PARM_SYNTAX_ERROR = 3097
MQRCCF_PWD_LENGTH_ERROR = 3098
MQRCCF_FILTER_ERROR = 3150
MQRCCF_WRONG_USER = 3151
MQRCCF_DUPLICATE_SUBSCRIPTION = 3152
MQRCCF_SUB_NAME_ERROR = 3153
MQRCCF_SUB_IDENTITY_ERROR = 3154
MQRCCF_SUBSCRIPTION_IN_USE = 3155
MQRCCF_SUBSCRIPTION_LOCKED = 3156
MQRCCF_ALREADY_JOINED = 3157
MQRCCF_OBJECT_IN_USE = 3160
MQRCCF_UNKNOWN_FILE_NAME = 3161
MQRCCF_FILE_NOT_AVAILABLE = 3162
MQRCCF_DISC_RETRY_ERROR = 3163
MQRCCF_ALLOC_RETRY_ERROR = 3164
MQRCCF_ALLOC_SLOW_TIMER_ERROR = 3165
MQRCCF_ALLOC_FAST_TIMER_ERROR = 3166
MQRCCF_PORT_NUMBER_ERROR = 3167
MQRCCF_CHL_SYSTEM_NOT_ACTIVE = 3168
MQRCCF_ENTITY_NAME_MISSING = 3169
MQRCCF_PROFILE_NAME_ERROR = 3170
MQRCCF_AUTH_VALUE_ERROR = 3171
MQRCCF_AUTH_VALUE_MISSING = 3172
MQRCCF_OBJECT_TYPE_MISSING = 3173
MQRCCF_CONNECTION_ID_ERROR = 3174
MQRCCF_LOG_TYPE_ERROR = 3175
MQRCCF_PROGRAM_NOT_AVAILABLE = 3176
MQRCCF_PROGRAM_AUTH_FAILED = 3177
MQRCCF_NONE_FOUND = 3200
MQRCCF_SECURITY_SWITCH_OFF = 3201
MQRCCF_SECURITY_REFRESH_FAILED = 3202
MQRCCF_PARM_CONFLICT = 3203
MQRCCF_COMMAND_INHIBITED = 3204
MQRCCF_OBJECT_BEING_DELETED = 3205
MQRCCF_STORAGE_CLASS_IN_USE = 3207
MQRCCF_OBJECT_NAME_RESTRICTED = 3208
MQRCCF_OBJECT_LIMIT_EXCEEDED = 3209
MQRCCF_OBJECT_OPEN_FORCE = 3210
MQRCCF_DISPOSITION_CONFLICT = 3211
MQRCCF_Q_MGR_NOT_IN_QSG = 3212
MQRCCF_ATTR_VALUE_FIXED = 3213
MQRCCF_NAMELIST_ERROR = 3215
MQRCCF_NO_CHANNEL_INITIATOR = 3217
MQRCCF_CHANNEL_INITIATOR_ERROR = 3218
MQRCCF_COMMAND_LEVEL_CONFLICT = 3222
MQRCCF_Q_ATTR_CONFLICT = 3223
MQRCCF_EVENTS_DISABLED = 3224
MQRCCF_COMMAND_SCOPE_ERROR = 3225
MQRCCF_COMMAND_REPLY_ERROR = 3226
MQRCCF_FUNCTION_RESTRICTED = 3227
MQRCCF_PARM_MISSING = 3228
MQRCCF_PARM_VALUE_ERROR = 3229
MQRCCF_COMMAND_LENGTH_ERROR = 3230
MQRCCF_COMMAND_ORIGIN_ERROR = 3231
MQRCCF_LISTENER_CONFLICT = 3232
MQRCCF_LISTENER_STARTED = 3233
MQRCCF_LISTENER_STOPPED = 3234
MQRCCF_CHANNEL_ERROR = 3235
MQRCCF_CF_STRUC_ERROR = 3236
MQRCCF_UNKNOWN_USER_ID = 3237
MQRCCF_UNEXPECTED_ERROR = 3238
MQRCCF_NO_XCF_PARTNER = 3239
MQRCCF_CFGR_PARM_ID_ERROR = 3240
MQRCCF_CFIF_LENGTH_ERROR = 3241
MQRCCF_CFIF_OPERATOR_ERROR = 3242
MQRCCF_CFIF_PARM_ID_ERROR = 3243
MQRCCF_CFSF_FILTER_VAL_LEN_ERR = 3244
MQRCCF_CFSF_LENGTH_ERROR = 3245
MQRCCF_CFSF_OPERATOR_ERROR = 3246
MQRCCF_CFSF_PARM_ID_ERROR = 3247
MQRCCF_TOO_MANY_FILTERS = 3248
MQRCCF_LISTENER_RUNNING = 3249
MQRCCF_LSTR_STATUS_NOT_FOUND = 3250
MQRCCF_SERVICE_RUNNING = 3251
MQRCCF_SERV_STATUS_NOT_FOUND = 3252
MQRCCF_SERVICE_STOPPED = 3253
MQRCCF_CFBS_DUPLICATE_PARM = 3254
MQRCCF_CFBS_LENGTH_ERROR = 3255
MQRCCF_CFBS_PARM_ID_ERROR = 3256
MQRCCF_CFBS_STRING_LENGTH_ERR = 3257
MQRCCF_CFGR_LENGTH_ERROR = 3258
MQRCCF_CFGR_PARM_COUNT_ERROR = 3259
MQRCCF_CONN_NOT_STOPPED = 3260
MQRCCF_SERVICE_REQUEST_PENDING = 3261
MQRCCF_NO_START_CMD = 3262
MQRCCF_NO_STOP_CMD = 3263
MQRCCF_CFBF_LENGTH_ERROR = 3264
MQRCCF_CFBF_PARM_ID_ERROR = 3265
MQRCCF_CFBF_OPERATOR_ERROR = 3266
MQRCCF_CFBF_FILTER_VAL_LEN_ERR = 3267
MQRCCF_LISTENER_STILL_ACTIVE = 3268
MQRCCF_TOPICSTR_ALREADY_EXISTS = 3300
MQRCCF_SHARING_CONVS_ERROR = 3301
MQRCCF_SHARING_CONVS_TYPE = 3302
MQRCCF_SECURITY_CASE_CONFLICT = 3303
MQRCCF_TOPIC_TYPE_ERROR = 3305
MQRCCF_MAX_INSTANCES_ERROR = 3306
MQRCCF_MAX_INSTS_PER_CLNT_ERR = 3307
MQRCCF_TOPIC_STRING_NOT_FOUND = 3308
MQRCCF_SUBSCRIPTION_POINT_ERR = 3309
MQRCCF_SUB_ALREADY_EXISTS = 3311
MQRCCF_UNKNOWN_OBJECT_NAME = 3312
MQRCCF_REMOTE_Q_NAME_ERROR = 3313
MQRCCF_DURABILITY_NOT_ALLOWED = 3314
MQRCCF_HOBJ_ERROR = 3315
MQRCCF_DEST_NAME_ERROR = 3316
MQRCCF_INVALID_DESTINATION = 3317
MQRCCF_PUBSUB_INHIBITED = 3318
MQRCCF_OBJECT_ALREADY_EXISTS = 4001
MQRCCF_OBJECT_WRONG_TYPE = 4002
MQRCCF_LIKE_OBJECT_WRONG_TYPE = 4003
MQRCCF_OBJECT_OPEN = 4004
MQRCCF_ATTR_VALUE_ERROR = 4005
MQRCCF_UNKNOWN_Q_MGR = 4006
MQRCCF_Q_WRONG_TYPE = 4007
MQRCCF_OBJECT_NAME_ERROR = 4008
MQRCCF_ALLOCATE_FAILED = 4009
MQRCCF_HOST_NOT_AVAILABLE = 4010
MQRCCF_CONFIGURATION_ERROR = 4011
MQRCCF_CONNECTION_REFUSED = 4012
MQRCCF_ENTRY_ERROR = 4013
MQRCCF_SEND_FAILED = 4014
MQRCCF_RECEIVED_DATA_ERROR = 4015
MQRCCF_RECEIVE_FAILED = 4016
MQRCCF_CONNECTION_CLOSED = 4017
MQRCCF_NO_STORAGE = 4018
MQRCCF_NO_COMMS_MANAGER = 4019
MQRCCF_LISTENER_NOT_STARTED = 4020
MQRCCF_BIND_FAILED = 4024
MQRCCF_CHANNEL_INDOUBT = 4025
MQRCCF_MQCONN_FAILED = 4026
MQRCCF_MQOPEN_FAILED = 4027
MQRCCF_MQGET_FAILED = 4028
MQRCCF_MQPUT_FAILED = 4029
MQRCCF_PING_ERROR = 4030
MQRCCF_CHANNEL_IN_USE = 4031
MQRCCF_CHANNEL_NOT_FOUND = 4032
MQRCCF_UNKNOWN_REMOTE_CHANNEL = 4033
MQRCCF_REMOTE_QM_UNAVAILABLE = 4034
MQRCCF_REMOTE_QM_TERMINATING = 4035
MQRCCF_MQINQ_FAILED = 4036
MQRCCF_NOT_XMIT_Q = 4037
MQRCCF_CHANNEL_DISABLED = 4038
MQRCCF_USER_EXIT_NOT_AVAILABLE = 4039
MQRCCF_COMMIT_FAILED = 4040
MQRCCF_WRONG_CHANNEL_TYPE = 4041
MQRCCF_CHANNEL_ALREADY_EXISTS = 4042
MQRCCF_DATA_TOO_LARGE = 4043
MQRCCF_CHANNEL_NAME_ERROR = 4044
MQRCCF_XMIT_Q_NAME_ERROR = 4045
MQRCCF_MCA_NAME_ERROR = 4047
MQRCCF_SEND_EXIT_NAME_ERROR = 4048
MQRCCF_SEC_EXIT_NAME_ERROR = 4049
MQRCCF_MSG_EXIT_NAME_ERROR = 4050
MQRCCF_RCV_EXIT_NAME_ERROR = 4051
MQRCCF_XMIT_Q_NAME_WRONG_TYPE = 4052
MQRCCF_MCA_NAME_WRONG_TYPE = 4053
MQRCCF_DISC_INT_WRONG_TYPE = 4054
MQRCCF_SHORT_RETRY_WRONG_TYPE = 4055
MQRCCF_SHORT_TIMER_WRONG_TYPE = 4056
MQRCCF_LONG_RETRY_WRONG_TYPE = 4057
MQRCCF_LONG_TIMER_WRONG_TYPE = 4058
MQRCCF_PUT_AUTH_WRONG_TYPE = 4059
MQRCCF_KEEP_ALIVE_INT_ERROR = 4060
MQRCCF_MISSING_CONN_NAME = 4061
MQRCCF_CONN_NAME_ERROR = 4062
MQRCCF_MQSET_FAILED = 4063
MQRCCF_CHANNEL_NOT_ACTIVE = 4064
MQRCCF_TERMINATED_BY_SEC_EXIT = 4065
MQRCCF_DYNAMIC_Q_SCOPE_ERROR = 4067
MQRCCF_CELL_DIR_NOT_AVAILABLE = 4068
MQRCCF_MR_COUNT_ERROR = 4069
MQRCCF_MR_COUNT_WRONG_TYPE = 4070
MQRCCF_MR_EXIT_NAME_ERROR = 4071
MQRCCF_MR_EXIT_NAME_WRONG_TYPE = 4072
MQRCCF_MR_INTERVAL_ERROR = 4073
MQRCCF_MR_INTERVAL_WRONG_TYPE = 4074
MQRCCF_NPM_SPEED_ERROR = 4075
MQRCCF_NPM_SPEED_WRONG_TYPE = 4076
MQRCCF_HB_INTERVAL_ERROR = 4077
MQRCCF_HB_INTERVAL_WRONG_TYPE = 4078
MQRCCF_CHAD_ERROR = 4079
MQRCCF_CHAD_WRONG_TYPE = 4080
MQRCCF_CHAD_EVENT_ERROR = 4081
MQRCCF_CHAD_EVENT_WRONG_TYPE = 4082
MQRCCF_CHAD_EXIT_ERROR = 4083
MQRCCF_CHAD_EXIT_WRONG_TYPE = 4084
MQRCCF_SUPPRESSED_BY_EXIT = 4085
MQRCCF_BATCH_INT_ERROR = 4086
MQRCCF_BATCH_INT_WRONG_TYPE = 4087
MQRCCF_NET_PRIORITY_ERROR = 4088
MQRCCF_NET_PRIORITY_WRONG_TYPE = 4089
MQRCCF_CHANNEL_CLOSED = 4090
MQRCCF_Q_STATUS_NOT_FOUND = 4091
MQRCCF_SSL_CIPHER_SPEC_ERROR = 4092
MQRCCF_SSL_PEER_NAME_ERROR = 4093
MQRCCF_SSL_CLIENT_AUTH_ERROR = 4094
MQRCCF_RETAINED_NOT_SUPPORTED = 4095
MQCFBF_STRUC_LENGTH_FIXED = 20
MQCFBS_STRUC_LENGTH_FIXED = 16
MQCFGR_STRUC_LENGTH = 16
MQCFIF_STRUC_LENGTH = 20
MQCFIL_STRUC_LENGTH_FIXED = 16
MQCFIL64_STRUC_LENGTH_FIXED = 16
MQCFIN_STRUC_LENGTH = 16
MQCFIN64_STRUC_LENGTH = 24
MQCFSF_STRUC_LENGTH_FIXED = 24
MQCFSL_STRUC_LENGTH_FIXED = 24
MQCFST_STRUC_LENGTH_FIXED = 20
MQEPH_STRUC_ID = "EPH "
MQEPH_STRUC_LENGTH_FIXED = 68
MQEPH_VERSION_1 = 1
MQEPH_CURRENT_VERSION = 1
MQEPH_NONE = 0x00000000
MQEPH_CCSID_EMBEDDED = 0x00000001
MQ_ARCHIVE_PFX_LENGTH = 36
MQ_ARCHIVE_UNIT_LENGTH = 8
MQ_ASID_LENGTH = 4
MQ_AUTH_PROFILE_NAME_LENGTH = 48
MQ_CF_LEID_LENGTH = 12
MQ_COMMAND_MQSC_LENGTH = 32768
MQ_DATA_SET_NAME_LENGTH = 44
MQ_DB2_NAME_LENGTH = 4
MQ_DSG_NAME_LENGTH = 8
MQ_ENTITY_NAME_LENGTH = 64
MQ_ENV_INFO_LENGTH = 96
MQ_IP_ADDRESS_LENGTH = 48
MQ_LOG_CORREL_ID_LENGTH = 8
MQ_LOG_EXTENT_NAME_LENGTH = 24
MQ_LOG_PATH_LENGTH = 1024
MQ_LRSN_LENGTH = 12
MQ_ORIGIN_NAME_LENGTH = 8
MQ_PSB_NAME_LENGTH = 8
MQ_PST_ID_LENGTH = 8
MQ_Q_MGR_CPF_LENGTH = 4
MQ_RESPONSE_ID_LENGTH = 24
MQ_RBA_LENGTH = 12
MQ_SECURITY_PROFILE_LENGTH = 40
MQ_SERVICE_COMPONENT_LENGTH = 48
MQ_SUB_NAME_LENGTH = 10240
MQ_SYSP_SERVICE_LENGTH = 32
MQ_SYSTEM_NAME_LENGTH = 8
MQ_TASK_NUMBER_LENGTH = 8
MQ_TPIPE_PFX_LENGTH = 4
MQ_UOW_ID_LENGTH = 256
MQ_USER_DATA_LENGTH = 10240
MQ_VOLSER_LENGTH = 6
MQCFOP_LESS = 1
MQCFOP_EQUAL = 2
MQCFOP_GREATER = 4
MQCFOP_NOT_LESS = 6
MQCFOP_NOT_EQUAL = 5
MQCFOP_NOT_GREATER = 3
MQCFOP_LIKE = 18
MQCFOP_NOT_LIKE = 21
MQCFOP_CONTAINS = 10
MQCFOP_EXCLUDES = 13
MQCFOP_CONTAINS_GEN = 26
MQCFOP_EXCLUDES_GEN = 29
MQCFT_NONE = 0
MQCFT_COMMAND = 1
MQCFT_RESPONSE = 2
MQCFT_INTEGER = 3
MQCFT_STRING = 4
MQCFT_INTEGER_LIST = 5
MQCFT_STRING_LIST = 6
MQCFT_EVENT = 7
MQCFT_USER = 8
MQCFT_BYTE_STRING = 9
MQCFT_TRACE_ROUTE = 10
MQCFT_REPORT = 12
MQCFT_INTEGER_FILTER = 13
MQCFT_STRING_FILTER = 14
MQCFT_BYTE_STRING_FILTER = 15
MQCFT_COMMAND_XR = 16
MQCFT_XR_MSG = 17
MQCFT_XR_ITEM = 18
MQCFT_XR_SUMMARY = 19
MQCFT_GROUP = 20
MQCFT_STATISTICS = 21
MQCFT_ACCOUNTING = 22
MQCFT_INTEGER64 = 23
MQCFT_INTEGER64_LIST = 25
MQBACF_FIRST = 7001
MQBACF_EVENT_ACCOUNTING_TOKEN = 7001
MQBACF_EVENT_SECURITY_ID = 7002
MQBACF_RESPONSE_SET = 7003
MQBACF_RESPONSE_ID = 7004
MQBACF_EXTERNAL_UOW_ID = 7005
MQBACF_CONNECTION_ID = 7006
MQBACF_GENERIC_CONNECTION_ID = 7007
MQBACF_ORIGIN_UOW_ID = 7008
MQBACF_Q_MGR_UOW_ID = 7009
MQBACF_ACCOUNTING_TOKEN = 7010
MQBACF_CORREL_ID = 7011
MQBACF_GROUP_ID = 7012
MQBACF_MSG_ID = 7013
MQBACF_CF_LEID = 7014
MQBACF_DESTINATION_CORREL_ID = 7015
MQBACF_SUB_ID = 7016
MQBACF_LAST_USED = 7016
MQIAMO_FIRST = 701
MQIAMO_AVG_BATCH_SIZE = 702
MQIAMO_AVG_Q_TIME = 703
MQIAMO_BACKOUTS = 704
MQIAMO_BROWSES = 705
MQIAMO_BROWSE_MAX_BYTES = 706
MQIAMO_BROWSE_MIN_BYTES = 707
MQIAMO_BROWSES_FAILED = 708
MQIAMO_CLOSES = 709
MQIAMO_COMMITS = 710
MQIAMO_COMMITS_FAILED = 711
MQIAMO_CONNS = 712
MQIAMO_CONNS_MAX = 713
MQIAMO_DISCS = 714
MQIAMO_DISCS_IMPLICIT = 715
MQIAMO_DISC_TYPE = 716
MQIAMO_EXIT_TIME_AVG = 717
MQIAMO_EXIT_TIME_MAX = 718
MQIAMO_EXIT_TIME_MIN = 719
MQIAMO_FULL_BATCHES = 720
MQIAMO_GENERATED_MSGS = 721
MQIAMO_GETS = 722
MQIAMO_GET_MAX_BYTES = 723
MQIAMO_GET_MIN_BYTES = 724
MQIAMO_GETS_FAILED = 725
MQIAMO_INCOMPLETE_BATCHES = 726
MQIAMO_INQS = 727
MQIAMO_MSGS = 728
MQIAMO_NET_TIME_AVG = 729
MQIAMO_NET_TIME_MAX = 730
MQIAMO_NET_TIME_MIN = 731
MQIAMO_OBJECT_COUNT = 732
MQIAMO_OPENS = 733
MQIAMO_PUT1S = 734
MQIAMO_PUTS = 735
MQIAMO_PUT_MAX_BYTES = 736
MQIAMO_PUT_MIN_BYTES = 737
MQIAMO_PUT_RETRIES = 738
MQIAMO_Q_MAX_DEPTH = 739
MQIAMO_Q_MIN_DEPTH = 740
MQIAMO_Q_TIME_AVG = 741
MQIAMO_Q_TIME_MAX = 742
MQIAMO_Q_TIME_MIN = 743
MQIAMO_SETS = 744
MQIAMO_CONNS_FAILED = 749
MQIAMO_OPENS_FAILED = 751
MQIAMO_INQS_FAILED = 752
MQIAMO_SETS_FAILED = 753
MQIAMO_PUTS_FAILED = 754
MQIAMO_PUT1S_FAILED = 755
MQIAMO_CLOSES_FAILED = 757
MQIAMO_MSGS_EXPIRED = 758
MQIAMO_MSGS_NOT_QUEUED = 759
MQIAMO_MSGS_PURGED = 760
MQIAMO_SUBS_DUR = 764
MQIAMO_SUBS_NDUR = 765
MQIAMO_SUBS_FAILED = 766
MQIAMO_SUBRQS = 767
MQIAMO_SUBRQS_FAILED = 768
MQIAMO_CBS = 769
MQIAMO_CBS_FAILED = 770
MQIAMO_CTLS = 771
MQIAMO_CTLS_FAILED = 772
MQIAMO_STATS = 773
MQIAMO_STATS_FAILED = 774
MQIAMO_SUB_DUR_HIGHWATER = 775
MQIAMO_SUB_DUR_LOWWATER = 776
MQIAMO_SUB_NDUR_HIGHWATER = 777
MQIAMO_SUB_NDUR_LOWWATER = 778
MQIAMO_TOPIC_PUTS = 779
MQIAMO_TOPIC_PUTS_FAILED = 780
MQIAMO_TOPIC_PUT1S = 781
MQIAMO_TOPIC_PUT1S_FAILED = 782
MQIAMO_PUBLISH_MSG_COUNT = 784
MQIAMO_UNSUBS_DUR = 786
MQIAMO_UNSUBS_NDUR = 787
MQIAMO_UNSUBS_FAILED = 788
MQIAMO_LAST_USED = 788
MQIAMO64_AVG_Q_TIME = 703
MQIAMO64_Q_TIME_AVG = 741
MQIAMO64_Q_TIME_MAX = 742
MQIAMO64_Q_TIME_MIN = 743
MQIAMO64_BROWSE_BYTES = 745
MQIAMO64_BYTES = 746
MQIAMO64_GET_BYTES = 747
MQIAMO64_PUT_BYTES = 748
MQIAMO64_TOPIC_PUT_BYTES = 783
MQIAMO64_PUBLISH_MSG_BYTES = 785
MQIACF_FIRST = 1001
MQIACF_Q_MGR_ATTRS = 1001
MQIACF_Q_ATTRS = 1002
MQIACF_PROCESS_ATTRS = 1003
MQIACF_NAMELIST_ATTRS = 1004
MQIACF_FORCE = 1005
MQIACF_REPLACE = 1006
MQIACF_PURGE = 1007
MQIACF_QUIESCE = 1008
MQIACF_MODE = 1008
MQIACF_ALL = 1009
MQIACF_EVENT_APPL_TYPE = 1010
MQIACF_EVENT_ORIGIN = 1011
MQIACF_PARAMETER_ID = 1012
MQIACF_ERROR_ID = 1013
MQIACF_ERROR_IDENTIFIER = 1013
MQIACF_SELECTOR = 1014
MQIACF_CHANNEL_ATTRS = 1015
MQIACF_OBJECT_TYPE = 1016
MQIACF_ESCAPE_TYPE = 1017
MQIACF_ERROR_OFFSET = 1018
MQIACF_AUTH_INFO_ATTRS = 1019
MQIACF_REASON_QUALIFIER = 1020
MQIACF_COMMAND = 1021
MQIACF_OPEN_OPTIONS = 1022
MQIACF_OPEN_TYPE = 1023
MQIACF_PROCESS_ID = 1024
MQIACF_THREAD_ID = 1025
MQIACF_Q_STATUS_ATTRS = 1026
MQIACF_UNCOMMITTED_MSGS = 1027
MQIACF_HANDLE_STATE = 1028
MQIACF_AUX_ERROR_DATA_INT_1 = 1070
MQIACF_AUX_ERROR_DATA_INT_2 = 1071
MQIACF_CONV_REASON_CODE = 1072
MQIACF_BRIDGE_TYPE = 1073
MQIACF_INQUIRY = 1074
MQIACF_WAIT_INTERVAL = 1075
MQIACF_OPTIONS = 1076
MQIACF_BROKER_OPTIONS = 1077
MQIACF_REFRESH_TYPE = 1078
MQIACF_SEQUENCE_NUMBER = 1079
MQIACF_INTEGER_DATA = 1080
MQIACF_REGISTRATION_OPTIONS = 1081
MQIACF_PUBLICATION_OPTIONS = 1082
MQIACF_CLUSTER_INFO = 1083
MQIACF_Q_MGR_DEFINITION_TYPE = 1084
MQIACF_Q_MGR_TYPE = 1085
MQIACF_ACTION = 1086
MQIACF_SUSPEND = 1087
MQIACF_BROKER_COUNT = 1088
MQIACF_APPL_COUNT = 1089
MQIACF_ANONYMOUS_COUNT = 1090
MQIACF_REG_REG_OPTIONS = 1091
MQIACF_DELETE_OPTIONS = 1092
MQIACF_CLUSTER_Q_MGR_ATTRS = 1093
MQIACF_REFRESH_INTERVAL = 1094
MQIACF_REFRESH_REPOSITORY = 1095
MQIACF_REMOVE_QUEUES = 1096
MQIACF_OPEN_INPUT_TYPE = 1098
MQIACF_OPEN_OUTPUT = 1099
MQIACF_OPEN_SET = 1100
MQIACF_OPEN_INQUIRE = 1101
MQIACF_OPEN_BROWSE = 1102
MQIACF_Q_STATUS_TYPE = 1103
MQIACF_Q_HANDLE = 1104
MQIACF_Q_STATUS = 1105
MQIACF_SECURITY_TYPE = 1106
MQIACF_CONNECTION_ATTRS = 1107
MQIACF_CONNECT_OPTIONS = 1108
MQIACF_CONN_INFO_TYPE = 1110
MQIACF_CONN_INFO_CONN = 1111
MQIACF_CONN_INFO_HANDLE = 1112
MQIACF_CONN_INFO_ALL = 1113
MQIACF_AUTH_PROFILE_ATTRS = 1114
MQIACF_AUTHORIZATION_LIST = 1115
MQIACF_AUTH_ADD_AUTHS = 1116
MQIACF_AUTH_REMOVE_AUTHS = 1117
MQIACF_ENTITY_TYPE = 1118
MQIACF_COMMAND_INFO = 1120
MQIACF_CMDSCOPE_Q_MGR_COUNT = 1121
MQIACF_Q_MGR_SYSTEM = 1122
MQIACF_Q_MGR_EVENT = 1123
MQIACF_Q_MGR_DQM = 1124
MQIACF_Q_MGR_CLUSTER = 1125
MQIACF_QSG_DISPS = 1126
MQIACF_UOW_STATE = 1128
MQIACF_SECURITY_ITEM = 1129
MQIACF_CF_STRUC_STATUS = 1130
MQIACF_UOW_TYPE = 1132
MQIACF_CF_STRUC_ATTRS = 1133
MQIACF_EXCLUDE_INTERVAL = 1134
MQIACF_CF_STATUS_TYPE = 1135
MQIACF_CF_STATUS_SUMMARY = 1136
MQIACF_CF_STATUS_CONNECT = 1137
MQIACF_CF_STATUS_BACKUP = 1138
MQIACF_CF_STRUC_TYPE = 1139
MQIACF_CF_STRUC_SIZE_MAX = 1140
MQIACF_CF_STRUC_SIZE_USED = 1141
MQIACF_CF_STRUC_ENTRIES_MAX = 1142
MQIACF_CF_STRUC_ENTRIES_USED = 1143
MQIACF_CF_STRUC_BACKUP_SIZE = 1144
MQIACF_MOVE_TYPE = 1145
MQIACF_MOVE_TYPE_MOVE = 1146
MQIACF_MOVE_TYPE_ADD = 1147
MQIACF_Q_MGR_NUMBER = 1148
MQIACF_Q_MGR_STATUS = 1149
MQIACF_DB2_CONN_STATUS = 1150
MQIACF_SECURITY_ATTRS = 1151
MQIACF_SECURITY_TIMEOUT = 1152
MQIACF_SECURITY_INTERVAL = 1153
MQIACF_SECURITY_SWITCH = 1154
MQIACF_SECURITY_SETTING = 1155
MQIACF_STORAGE_CLASS_ATTRS = 1156
MQIACF_USAGE_TYPE = 1157
MQIACF_BUFFER_POOL_ID = 1158
MQIACF_USAGE_TOTAL_PAGES = 1159
MQIACF_USAGE_UNUSED_PAGES = 1160
MQIACF_USAGE_PERSIST_PAGES = 1161
MQIACF_USAGE_NONPERSIST_PAGES = 1162
MQIACF_USAGE_RESTART_EXTENTS = 1163
MQIACF_USAGE_EXPAND_COUNT = 1164
MQIACF_PAGESET_STATUS = 1165
MQIACF_USAGE_TOTAL_BUFFERS = 1166
MQIACF_USAGE_DATA_SET_TYPE = 1167
MQIACF_USAGE_PAGESET = 1168
MQIACF_USAGE_DATA_SET = 1169
MQIACF_USAGE_BUFFER_POOL = 1170
MQIACF_MOVE_COUNT = 1171
MQIACF_EXPIRY_Q_COUNT = 1172
MQIACF_CONFIGURATION_OBJECTS = 1173
MQIACF_CONFIGURATION_EVENTS = 1174
MQIACF_SYSP_TYPE = 1175
MQIACF_SYSP_DEALLOC_INTERVAL = 1176
MQIACF_SYSP_MAX_ARCHIVE = 1177
MQIACF_SYSP_MAX_READ_TAPES = 1178
MQIACF_SYSP_IN_BUFFER_SIZE = 1179
MQIACF_SYSP_OUT_BUFFER_SIZE = 1180
MQIACF_SYSP_OUT_BUFFER_COUNT = 1181
MQIACF_SYSP_ARCHIVE = 1182
MQIACF_SYSP_DUAL_ACTIVE = 1183
MQIACF_SYSP_DUAL_ARCHIVE = 1184
MQIACF_SYSP_DUAL_BSDS = 1185
MQIACF_SYSP_MAX_CONNS = 1186
MQIACF_SYSP_MAX_CONNS_FORE = 1187
MQIACF_SYSP_MAX_CONNS_BACK = 1188
MQIACF_SYSP_EXIT_INTERVAL = 1189
MQIACF_SYSP_EXIT_TASKS = 1190
MQIACF_SYSP_CHKPOINT_COUNT = 1191
MQIACF_SYSP_OTMA_INTERVAL = 1192
MQIACF_SYSP_Q_INDEX_DEFER = 1193
MQIACF_SYSP_DB2_TASKS = 1194
MQIACF_SYSP_RESLEVEL_AUDIT = 1195
MQIACF_SYSP_ROUTING_CODE = 1196
MQIACF_SYSP_SMF_ACCOUNTING = 1197
MQIACF_SYSP_SMF_STATS = 1198
MQIACF_SYSP_SMF_INTERVAL = 1199
MQIACF_SYSP_TRACE_CLASS = 1200
MQIACF_SYSP_TRACE_SIZE = 1201
MQIACF_SYSP_WLM_INTERVAL = 1202
MQIACF_SYSP_ALLOC_UNIT = 1203
MQIACF_SYSP_ARCHIVE_RETAIN = 1204
MQIACF_SYSP_ARCHIVE_WTOR = 1205
MQIACF_SYSP_BLOCK_SIZE = 1206
MQIACF_SYSP_CATALOG = 1207
MQIACF_SYSP_COMPACT = 1208
MQIACF_SYSP_ALLOC_PRIMARY = 1209
MQIACF_SYSP_ALLOC_SECONDARY = 1210
MQIACF_SYSP_PROTECT = 1211
MQIACF_SYSP_QUIESCE_INTERVAL = 1212
MQIACF_SYSP_TIMESTAMP = 1213
MQIACF_SYSP_UNIT_ADDRESS = 1214
MQIACF_SYSP_UNIT_STATUS = 1215
MQIACF_SYSP_LOG_COPY = 1216
MQIACF_SYSP_LOG_USED = 1217
MQIACF_SYSP_LOG_SUSPEND = 1218
MQIACF_SYSP_OFFLOAD_STATUS = 1219
MQIACF_SYSP_TOTAL_LOGS = 1220
MQIACF_SYSP_FULL_LOGS = 1221
MQIACF_LISTENER_ATTRS = 1222
MQIACF_LISTENER_STATUS_ATTRS = 1223
MQIACF_SERVICE_ATTRS = 1224
MQIACF_SERVICE_STATUS_ATTRS = 1225
MQIACF_Q_TIME_INDICATOR = 1226
MQIACF_OLDEST_MSG_AGE = 1227
MQIACF_AUTH_OPTIONS = 1228
MQIACF_Q_MGR_STATUS_ATTRS = 1229
MQIACF_CONNECTION_COUNT = 1230
MQIACF_Q_MGR_FACILITY = 1231
MQIACF_CHINIT_STATUS = 1232
MQIACF_CMD_SERVER_STATUS = 1233
MQIACF_ROUTE_DETAIL = 1234
MQIACF_RECORDED_ACTIVITIES = 1235
MQIACF_MAX_ACTIVITIES = 1236
MQIACF_DISCONTINUITY_COUNT = 1237
MQIACF_ROUTE_ACCUMULATION = 1238
MQIACF_ROUTE_DELIVERY = 1239
MQIACF_OPERATION_TYPE = 1240
MQIACF_BACKOUT_COUNT = 1241
MQIACF_COMP_CODE = 1242
MQIACF_ENCODING = 1243
MQIACF_EXPIRY = 1244
MQIACF_FEEDBACK = 1245
MQIACF_MSG_FLAGS = 1247
MQIACF_MSG_LENGTH = 1248
MQIACF_MSG_TYPE = 1249
MQIACF_OFFSET = 1250
MQIACF_ORIGINAL_LENGTH = 1251
MQIACF_PERSISTENCE = 1252
MQIACF_PRIORITY = 1253
MQIACF_REASON_CODE = 1254
MQIACF_REPORT = 1255
MQIACF_VERSION = 1256
MQIACF_UNRECORDED_ACTIVITIES = 1257
MQIACF_MONITORING = 1258
MQIACF_ROUTE_FORWARDING = 1259
MQIACF_SERVICE_STATUS = 1260
MQIACF_Q_TYPES = 1261
MQIACF_USER_ID_SUPPORT = 1262
MQIACF_INTERFACE_VERSION = 1263
MQIACF_AUTH_SERVICE_ATTRS = 1264
MQIACF_USAGE_EXPAND_TYPE = 1265
MQIACF_SYSP_CLUSTER_CACHE = 1266
MQIACF_SYSP_DB2_BLOB_TASKS = 1267
MQIACF_SYSP_WLM_INT_UNITS = 1268
MQIACF_TOPIC_ATTRS = 1269
MQIACF_PUBSUB_PROPERTIES = 1271
MQIACF_DESTINATION_CLASS = 1273
MQIACF_DURABLE_SUBSCRIPTION = 1274
MQIACF_SUBSCRIPTION_SCOPE = 1275
MQIACF_VARIABLE_USER_ID = 1277
MQIACF_REQUEST_ONLY = 1280
MQIACF_PUB_PRIORITY = 1283
MQIACF_SUB_ATTRS = 1287
MQIACF_WILDCARD_SCHEMA = 1288
MQIACF_SUB_TYPE = 1289
MQIACF_MESSAGE_COUNT = 1290
MQIACF_Q_MGR_PUBSUB = 1291
MQIACF_Q_MGR_VERSION = 1292
MQIACF_SUB_STATUS_ATTRS = 1294
MQIACF_TOPIC_STATUS = 1295
MQIACF_TOPIC_SUB = 1296
MQIACF_TOPIC_PUB = 1297
MQIACF_RETAINED_PUBLICATION = 1300
MQIACF_TOPIC_STATUS_ATTRS = 1301
MQIACF_TOPIC_STATUS_TYPE = 1302
MQIACF_SUB_OPTIONS = 1303
MQIACF_PUBLISH_COUNT = 1304
MQIACF_CLEAR_TYPE = 1305
MQIACF_CLEAR_SCOPE = 1306
MQIACF_SUB_LEVEL = 1307
MQIACF_ASYNC_STATE = 1308
MQIACF_SUB_SUMMARY = 1309
MQIACF_OBSOLETE_MSGS = 1310
MQIACF_PUBSUB_STATUS = 1311
MQIACF_PS_STATUS_TYPE = 1314
MQIACF_PUBSUB_STATUS_ATTRS = 1318
MQIACF_LAST_USED = 1318
MQIACH_FIRST = 1501
MQIACH_XMIT_PROTOCOL_TYPE = 1501
MQIACH_BATCH_SIZE = 1502
MQIACH_DISC_INTERVAL = 1503
MQIACH_SHORT_TIMER = 1504
MQIACH_SHORT_RETRY = 1505
MQIACH_LONG_TIMER = 1506
MQIACH_LONG_RETRY = 1507
MQIACH_PUT_AUTHORITY = 1508
MQIACH_SEQUENCE_NUMBER_WRAP = 1509
MQIACH_MAX_MSG_LENGTH = 1510
MQIACH_CHANNEL_TYPE = 1511
MQIACH_DATA_COUNT = 1512
MQIACH_NAME_COUNT = 1513
MQIACH_MSG_SEQUENCE_NUMBER = 1514
MQIACH_DATA_CONVERSION = 1515
MQIACH_IN_DOUBT = 1516
MQIACH_MCA_TYPE = 1517
MQIACH_SESSION_COUNT = 1518
MQIACH_ADAPTER = 1519
MQIACH_COMMAND_COUNT = 1520
MQIACH_SOCKET = 1521
MQIACH_PORT = 1522
MQIACH_CHANNEL_INSTANCE_TYPE = 1523
MQIACH_CHANNEL_INSTANCE_ATTRS = 1524
MQIACH_CHANNEL_ERROR_DATA = 1525
MQIACH_CHANNEL_TABLE = 1526
MQIACH_CHANNEL_STATUS = 1527
MQIACH_INDOUBT_STATUS = 1528
MQIACH_LAST_SEQ_NUMBER = 1529
MQIACH_LAST_SEQUENCE_NUMBER = 1529
MQIACH_CURRENT_MSGS = 1531
MQIACH_CURRENT_SEQ_NUMBER = 1532
MQIACH_CURRENT_SEQUENCE_NUMBER = 1532
MQIACH_SSL_RETURN_CODE = 1533
MQIACH_MSGS = 1534
MQIACH_BYTES_SENT = 1535
MQIACH_BYTES_RCVD = 1536
MQIACH_BYTES_RECEIVED = 1536
MQIACH_BATCHES = 1537
MQIACH_BUFFERS_SENT = 1538
MQIACH_BUFFERS_RCVD = 1539
MQIACH_BUFFERS_RECEIVED = 1539
MQIACH_LONG_RETRIES_LEFT = 1540
MQIACH_SHORT_RETRIES_LEFT = 1541
MQIACH_MCA_STATUS = 1542
MQIACH_STOP_REQUESTED = 1543
MQIACH_MR_COUNT = 1544
MQIACH_MR_INTERVAL = 1545
MQIACH_NPM_SPEED = 1562
MQIACH_HB_INTERVAL = 1563
MQIACH_BATCH_INTERVAL = 1564
MQIACH_NETWORK_PRIORITY = 1565
MQIACH_KEEP_ALIVE_INTERVAL = 1566
MQIACH_BATCH_HB = 1567
MQIACH_SSL_CLIENT_AUTH = 1568
MQIACH_ALLOC_RETRY = 1570
MQIACH_ALLOC_FAST_TIMER = 1571
MQIACH_ALLOC_SLOW_TIMER = 1572
MQIACH_DISC_RETRY = 1573
MQIACH_PORT_NUMBER = 1574
MQIACH_HDR_COMPRESSION = 1575
MQIACH_MSG_COMPRESSION = 1576
MQIACH_CLWL_CHANNEL_RANK = 1577
MQIACH_CLWL_CHANNEL_PRIORITY = 1578
MQIACH_CLWL_CHANNEL_WEIGHT = 1579
MQIACH_CHANNEL_DISP = 1580
MQIACH_INBOUND_DISP = 1581
MQIACH_CHANNEL_TYPES = 1582
MQIACH_ADAPS_STARTED = 1583
MQIACH_ADAPS_MAX = 1584
MQIACH_DISPS_STARTED = 1585
MQIACH_DISPS_MAX = 1586
MQIACH_SSLTASKS_STARTED = 1587
MQIACH_SSLTASKS_MAX = 1588
MQIACH_CURRENT_CHL = 1589
MQIACH_CURRENT_CHL_MAX = 1590
MQIACH_CURRENT_CHL_TCP = 1591
MQIACH_CURRENT_CHL_LU62 = 1592
MQIACH_ACTIVE_CHL = 1593
MQIACH_ACTIVE_CHL_MAX = 1594
MQIACH_ACTIVE_CHL_PAUSED = 1595
MQIACH_ACTIVE_CHL_STARTED = 1596
MQIACH_ACTIVE_CHL_STOPPED = 1597
MQIACH_ACTIVE_CHL_RETRY = 1598
MQIACH_LISTENER_STATUS = 1599
MQIACH_SHARED_CHL_RESTART = 1600
MQIACH_LISTENER_CONTROL = 1601
MQIACH_BACKLOG = 1602
MQIACH_XMITQ_TIME_INDICATOR = 1604
MQIACH_NETWORK_TIME_INDICATOR = 1605
MQIACH_EXIT_TIME_INDICATOR = 1606
MQIACH_BATCH_SIZE_INDICATOR = 1607
MQIACH_XMITQ_MSGS_AVAILABLE = 1608
MQIACH_CHANNEL_SUBSTATE = 1609
MQIACH_SSL_KEY_RESETS = 1610
MQIACH_COMPRESSION_RATE = 1611
MQIACH_COMPRESSION_TIME = 1612
MQIACH_MAX_XMIT_SIZE = 1613
MQIACH_DEF_CHANNEL_DISP = 1614
MQIACH_SHARING_CONVERSATIONS = 1615
MQIACH_MAX_SHARING_CONVS = 1616
MQIACH_CURRENT_SHARING_CONVS = 1617
MQIACH_MAX_INSTANCES = 1618
MQIACH_MAX_INSTS_PER_CLIENT = 1619
MQIACH_CLIENT_CHANNEL_WEIGHT = 1620
MQIACH_CONNECTION_AFFINITY = 1621
MQIACH_LAST_USED = 1621
MQCAMO_FIRST = 2701
MQCAMO_CLOSE_DATE = 2701
MQCAMO_CLOSE_TIME = 2702
MQCAMO_CONN_DATE = 2703
MQCAMO_CONN_TIME = 2704
MQCAMO_DISC_DATE = 2705
MQCAMO_DISC_TIME = 2706
MQCAMO_END_DATE = 2707
MQCAMO_END_TIME = 2708
MQCAMO_OPEN_DATE = 2709
MQCAMO_OPEN_TIME = 2710
MQCAMO_START_DATE = 2711
MQCAMO_START_TIME = 2712
MQCAMO_LAST_USED = 2712
MQCACF_FIRST = 3001
MQCACF_FROM_Q_NAME = 3001
MQCACF_TO_Q_NAME = 3002
MQCACF_FROM_PROCESS_NAME = 3003
MQCACF_TO_PROCESS_NAME = 3004
MQCACF_FROM_NAMELIST_NAME = 3005
MQCACF_TO_NAMELIST_NAME = 3006
MQCACF_FROM_CHANNEL_NAME = 3007
MQCACF_TO_CHANNEL_NAME = 3008
MQCACF_FROM_AUTH_INFO_NAME = 3009
MQCACF_TO_AUTH_INFO_NAME = 3010
MQCACF_Q_NAMES = 3011
MQCACF_PROCESS_NAMES = 3012
MQCACF_NAMELIST_NAMES = 3013
MQCACF_ESCAPE_TEXT = 3014
MQCACF_LOCAL_Q_NAMES = 3015
MQCACF_MODEL_Q_NAMES = 3016
MQCACF_ALIAS_Q_NAMES = 3017
MQCACF_REMOTE_Q_NAMES = 3018
MQCACF_SENDER_CHANNEL_NAMES = 3019
MQCACF_SERVER_CHANNEL_NAMES = 3020
MQCACF_REQUESTER_CHANNEL_NAMES = 3021
MQCACF_RECEIVER_CHANNEL_NAMES = 3022
MQCACF_OBJECT_Q_MGR_NAME = 3023
MQCACF_APPL_NAME = 3024
MQCACF_USER_IDENTIFIER = 3025
MQCACF_AUX_ERROR_DATA_STR_1 = 3026
MQCACF_AUX_ERROR_DATA_STR_2 = 3027
MQCACF_AUX_ERROR_DATA_STR_3 = 3028
MQCACF_BRIDGE_NAME = 3029
MQCACF_STREAM_NAME = 3030
MQCACF_TOPIC = 3031
MQCACF_PARENT_Q_MGR_NAME = 3032
MQCACF_CORREL_ID = 3033
MQCACF_PUBLISH_TIMESTAMP = 3034
MQCACF_STRING_DATA = 3035
MQCACF_SUPPORTED_STREAM_NAME = 3036
MQCACF_REG_TOPIC = 3037
MQCACF_REG_TIME = 3038
MQCACF_REG_USER_ID = 3039
MQCACF_CHILD_Q_MGR_NAME = 3040
MQCACF_REG_STREAM_NAME = 3041
MQCACF_REG_Q_MGR_NAME = 3042
MQCACF_REG_Q_NAME = 3043
MQCACF_REG_CORREL_ID = 3044
MQCACF_EVENT_USER_ID = 3045
MQCACF_OBJECT_NAME = 3046
MQCACF_EVENT_Q_MGR = 3047
MQCACF_AUTH_INFO_NAMES = 3048
MQCACF_EVENT_APPL_IDENTITY = 3049
MQCACF_EVENT_APPL_NAME = 3050
MQCACF_EVENT_APPL_ORIGIN = 3051
MQCACF_SUBSCRIPTION_NAME = 3052
MQCACF_REG_SUB_NAME = 3053
MQCACF_SUBSCRIPTION_IDENTITY = 3054
MQCACF_REG_SUB_IDENTITY = 3055
MQCACF_SUBSCRIPTION_USER_DATA = 3056
MQCACF_REG_SUB_USER_DATA = 3057
MQCACF_APPL_TAG = 3058
MQCACF_DATA_SET_NAME = 3059
MQCACF_UOW_START_DATE = 3060
MQCACF_UOW_START_TIME = 3061
MQCACF_UOW_LOG_START_DATE = 3062
MQCACF_UOW_LOG_START_TIME = 3063
MQCACF_UOW_LOG_EXTENT_NAME = 3064
MQCACF_PRINCIPAL_ENTITY_NAMES = 3065
MQCACF_GROUP_ENTITY_NAMES = 3066
MQCACF_AUTH_PROFILE_NAME = 3067
MQCACF_ENTITY_NAME = 3068
MQCACF_SERVICE_COMPONENT = 3069
MQCACF_RESPONSE_Q_MGR_NAME = 3070
MQCACF_CURRENT_LOG_EXTENT_NAME = 3071
MQCACF_RESTART_LOG_EXTENT_NAME = 3072
MQCACF_MEDIA_LOG_EXTENT_NAME = 3073
MQCACF_LOG_PATH = 3074
MQCACF_COMMAND_MQSC = 3075
MQCACF_Q_MGR_CPF = 3076
MQCACF_USAGE_LOG_RBA = 3078
MQCACF_USAGE_LOG_LRSN = 3079
MQCACF_COMMAND_SCOPE = 3080
MQCACF_ASID = 3081
MQCACF_PSB_NAME = 3082
MQCACF_PST_ID = 3083
MQCACF_TASK_NUMBER = 3084
MQCACF_TRANSACTION_ID = 3085
MQCACF_Q_MGR_UOW_ID = 3086
MQCACF_ORIGIN_NAME = 3088
MQCACF_ENV_INFO = 3089
MQCACF_SECURITY_PROFILE = 3090
MQCACF_CONFIGURATION_DATE = 3091
MQCACF_CONFIGURATION_TIME = 3092
MQCACF_FROM_CF_STRUC_NAME = 3093
MQCACF_TO_CF_STRUC_NAME = 3094
MQCACF_CF_STRUC_NAMES = 3095
MQCACF_FAIL_DATE = 3096
MQCACF_FAIL_TIME = 3097
MQCACF_BACKUP_DATE = 3098
MQCACF_BACKUP_TIME = 3099
MQCACF_SYSTEM_NAME = 3100
MQCACF_CF_STRUC_BACKUP_START = 3101
MQCACF_CF_STRUC_BACKUP_END = 3102
MQCACF_CF_STRUC_LOG_Q_MGRS = 3103
MQCACF_FROM_STORAGE_CLASS = 3104
MQCACF_TO_STORAGE_CLASS = 3105
MQCACF_STORAGE_CLASS_NAMES = 3106
MQCACF_DSG_NAME = 3108
MQCACF_DB2_NAME = 3109
MQCACF_SYSP_CMD_USER_ID = 3110
MQCACF_SYSP_OTMA_GROUP = 3111
MQCACF_SYSP_OTMA_MEMBER = 3112
MQCACF_SYSP_OTMA_DRU_EXIT = 3113
MQCACF_SYSP_OTMA_TPIPE_PFX = 3114
MQCACF_SYSP_ARCHIVE_PFX1 = 3115
MQCACF_SYSP_ARCHIVE_UNIT1 = 3116
MQCACF_SYSP_LOG_CORREL_ID = 3117
MQCACF_SYSP_UNIT_VOLSER = 3118
MQCACF_SYSP_Q_MGR_TIME = 3119
MQCACF_SYSP_Q_MGR_DATE = 3120
MQCACF_SYSP_Q_MGR_RBA = 3121
MQCACF_SYSP_LOG_RBA = 3122
MQCACF_SYSP_SERVICE = 3123
MQCACF_FROM_LISTENER_NAME = 3124
MQCACF_TO_LISTENER_NAME = 3125
MQCACF_FROM_SERVICE_NAME = 3126
MQCACF_TO_SERVICE_NAME = 3127
MQCACF_LAST_PUT_DATE = 3128
MQCACF_LAST_PUT_TIME = 3129
MQCACF_LAST_GET_DATE = 3130
MQCACF_LAST_GET_TIME = 3131
MQCACF_OPERATION_DATE = 3132
MQCACF_OPERATION_TIME = 3133
MQCACF_ACTIVITY_DESC = 3134
MQCACF_APPL_IDENTITY_DATA = 3135
MQCACF_APPL_ORIGIN_DATA = 3136
MQCACF_PUT_DATE = 3137
MQCACF_PUT_TIME = 3138
MQCACF_REPLY_TO_Q = 3139
MQCACF_REPLY_TO_Q_MGR = 3140
MQCACF_RESOLVED_Q_NAME = 3141
MQCACF_STRUC_ID = 3142
MQCACF_VALUE_NAME = 3143
MQCACF_SERVICE_START_DATE = 3144
MQCACF_SERVICE_START_TIME = 3145
MQCACF_SYSP_OFFLINE_RBA = 3146
MQCACF_SYSP_ARCHIVE_PFX2 = 3147
MQCACF_SYSP_ARCHIVE_UNIT2 = 3148
MQCACF_TO_TOPIC_NAME = 3149
MQCACF_FROM_TOPIC_NAME = 3150
MQCACF_TOPIC_NAMES = 3151
MQCACF_SUB_NAME = 3152
MQCACF_DESTINATION_Q_MGR = 3153
MQCACF_DESTINATION = 3154
MQCACF_SUB_USER_ID = 3156
MQCACF_SUB_USER_DATA = 3159
MQCACF_SUB_SELECTOR = 3160
MQCACF_LAST_PUB_DATE = 3161
MQCACF_LAST_PUB_TIME = 3162
MQCACF_FROM_SUB_NAME = 3163
MQCACF_TO_SUB_NAME = 3164
MQCACF_LAST_MSG_TIME = 3167
MQCACF_LAST_MSG_DATE = 3168
MQCACF_SUBSCRIPTION_POINT = 3169
MQCACF_FILTER = 3170
MQCACF_NONE = 3171
MQCACF_ADMIN_TOPIC_NAMES = 3172
MQCACF_LAST_USED = 3172
MQCACH_FIRST = 3501
MQCACH_CHANNEL_NAME = 3501
MQCACH_DESC = 3502
MQCACH_MODE_NAME = 3503
MQCACH_TP_NAME = 3504
MQCACH_XMIT_Q_NAME = 3505
MQCACH_CONNECTION_NAME = 3506
MQCACH_MCA_NAME = 3507
MQCACH_SEC_EXIT_NAME = 3508
MQCACH_MSG_EXIT_NAME = 3509
MQCACH_SEND_EXIT_NAME = 3510
MQCACH_RCV_EXIT_NAME = 3511
MQCACH_CHANNEL_NAMES = 3512
MQCACH_SEC_EXIT_USER_DATA = 3513
MQCACH_MSG_EXIT_USER_DATA = 3514
MQCACH_SEND_EXIT_USER_DATA = 3515
MQCACH_RCV_EXIT_USER_DATA = 3516
MQCACH_USER_ID = 3517
MQCACH_PASSWORD = 3518
MQCACH_LOCAL_ADDRESS = 3520
MQCACH_LOCAL_NAME = 3521
MQCACH_LAST_MSG_TIME = 3524
MQCACH_LAST_MSG_DATE = 3525
MQCACH_MCA_USER_ID = 3527
MQCACH_CHANNEL_START_TIME = 3528
MQCACH_CHANNEL_START_DATE = 3529
MQCACH_MCA_JOB_NAME = 3530
MQCACH_LAST_LUWID = 3531
MQCACH_CURRENT_LUWID = 3532
MQCACH_FORMAT_NAME = 3533
MQCACH_MR_EXIT_NAME = 3534
MQCACH_MR_EXIT_USER_DATA = 3535
MQCACH_SSL_CIPHER_SPEC = 3544
MQCACH_SSL_PEER_NAME = 3545
MQCACH_SSL_HANDSHAKE_STAGE = 3546
MQCACH_SSL_SHORT_PEER_NAME = 3547
MQCACH_REMOTE_APPL_TAG = 3548
MQCACH_SSL_CERT_USER_ID = 3549
MQCACH_SSL_CERT_ISSUER_NAME = 3550
MQCACH_LU_NAME = 3551
MQCACH_IP_ADDRESS = 3552
MQCACH_TCP_NAME = 3553
MQCACH_LISTENER_NAME = 3554
MQCACH_LISTENER_DESC = 3555
MQCACH_LISTENER_START_DATE = 3556
MQCACH_LISTENER_START_TIME = 3557
MQCACH_SSL_KEY_RESET_DATE = 3558
MQCACH_SSL_KEY_RESET_TIME = 3559
MQCACH_LAST_USED = 3559
MQGACF_FIRST = 8001
MQGACF_COMMAND_CONTEXT = 8001
MQGACF_COMMAND_DATA = 8002
MQGACF_TRACE_ROUTE = 8003
MQGACF_OPERATION = 8004
MQGACF_ACTIVITY = 8005
MQGACF_EMBEDDED_MQMD = 8006
MQGACF_MESSAGE = 8007
MQGACF_MQMD = 8008
MQGACF_VALUE_NAMING = 8009
MQGACF_Q_ACCOUNTING_DATA = 8010
MQGACF_Q_STATISTICS_DATA = 8011
MQGACF_CHL_STATISTICS_DATA = 8012
MQGACF_LAST_USED = 8012
MQACT_FORCE_REMOVE = 1
MQACT_ADVANCE_LOG = 2
MQACT_COLLECT_STATISTICS = 3
MQACT_PUBSUB = 4
MQAS_NONE = 0
MQAS_STARTED = 1
MQAS_START_WAIT = 2
MQAS_STOPPED = 3
MQAS_SUSPENDED = 4
MQAS_SUSPENDED_TEMPORARY = 5
MQAS_ACTIVE = 6
MQAS_INACTIVE = 7
MQAUTH_NONE = 0
MQAUTH_ALT_USER_AUTHORITY = 1
MQAUTH_BROWSE = 2
MQAUTH_CHANGE = 3
MQAUTH_CLEAR = 4
MQAUTH_CONNECT = 5
MQAUTH_CREATE = 6
MQAUTH_DELETE = 7
MQAUTH_DISPLAY = 8
MQAUTH_INPUT = 9
MQAUTH_INQUIRE = 10
MQAUTH_OUTPUT = 11
MQAUTH_PASS_ALL_CONTEXT = 12
MQAUTH_PASS_IDENTITY_CONTEXT = 13
MQAUTH_SET = 14
MQAUTH_SET_ALL_CONTEXT = 15
MQAUTH_SET_IDENTITY_CONTEXT = 16
MQAUTH_CONTROL = 17
MQAUTH_CONTROL_EXTENDED = 18
MQAUTH_PUBLISH = 19
MQAUTH_SUBSCRIBE = 20
MQAUTH_RESUME = 21
MQAUTHOPT_CUMULATIVE = 0x00000100
MQAUTHOPT_ENTITY_EXPLICIT = 0x00000001
MQAUTHOPT_ENTITY_SET = 0x00000002
MQAUTHOPT_NAME_ALL_MATCHING = 0x00000020
MQAUTHOPT_NAME_AS_WILDCARD = 0x00000040
MQAUTHOPT_NAME_EXPLICIT = 0x00000010
MQBT_OTMA = 1
MQCFO_REFRESH_REPOSITORY_YES = 1
MQCFO_REFRESH_REPOSITORY_NO = 0
MQCFO_REMOVE_QUEUES_YES = 1
MQCFO_REMOVE_QUEUES_NO = 0
MQCFSTATUS_NOT_FOUND = 0
MQCFSTATUS_ACTIVE = 1
MQCFSTATUS_IN_RECOVER = 2
MQCFSTATUS_IN_BACKUP = 3
MQCFSTATUS_FAILED = 4
MQCFSTATUS_NONE = 5
MQCFSTATUS_UNKNOWN = 6
MQCFSTATUS_ADMIN_INCOMPLETE = 20
MQCFSTATUS_NEVER_USED = 21
MQCFSTATUS_NO_BACKUP = 22
MQCFSTATUS_NOT_FAILED = 23
MQCFSTATUS_NOT_RECOVERABLE = 24
MQCFSTATUS_XES_ERROR = 25
MQCFTYPE_APPL = 0
MQCFTYPE_ADMIN = 1
MQCHIDS_NOT_INDOUBT = 0
MQCHIDS_INDOUBT = 1
MQCHLD_ALL = (-1)
MQCHLD_DEFAULT = 1
MQCHLD_SHARED = 2
MQCHLD_PRIVATE = 4
MQCHLD_FIXSHARED = 5
MQCHS_INACTIVE = 0
MQCHS_BINDING = 1
MQCHS_STARTING = 2
MQCHS_RUNNING = 3
MQCHS_STOPPING = 4
MQCHS_RETRYING = 5
MQCHS_STOPPED = 6
MQCHS_REQUESTING = 7
MQCHS_PAUSED = 8
MQCHS_INITIALIZING = 13
MQCHSSTATE_OTHER = 0
MQCHSSTATE_END_OF_BATCH = 100
MQCHSSTATE_SENDING = 200
MQCHSSTATE_RECEIVING = 300
MQCHSSTATE_SERIALIZING = 400
MQCHSSTATE_RESYNCHING = 500
MQCHSSTATE_HEARTBEATING = 600
MQCHSSTATE_IN_SCYEXIT = 700
MQCHSSTATE_IN_RCVEXIT = 800
MQCHSSTATE_IN_SENDEXIT = 900
MQCHSSTATE_IN_MSGEXIT = 1000
MQCHSSTATE_IN_MREXIT = 1100
MQCHSSTATE_IN_CHADEXIT = 1200
MQCHSSTATE_NET_CONNECTING = 1250
MQCHSSTATE_SSL_HANDSHAKING = 1300
MQCHSSTATE_NAME_SERVER = 1400
MQCHSSTATE_IN_MQPUT = 1500
MQCHSSTATE_IN_MQGET = 1600
MQCHSSTATE_IN_MQI_CALL = 1700
MQCHSSTATE_COMPRESSING = 1800
MQCHSH_RESTART_NO = 0
MQCHSH_RESTART_YES = 1
MQCHSR_STOP_NOT_REQUESTED = 0
MQCHSR_STOP_REQUESTED = 1
MQCHTAB_Q_MGR = 1
MQCHTAB_CLNTCONN = 2
MQCLRS_LOCAL = 1
MQCLRS_GLOBAL = 2
MQCLRT_RETAINED = 1
MQCMDI_CMDSCOPE_ACCEPTED = 1
MQCMDI_CMDSCOPE_GENERATED = 2
MQCMDI_CMDSCOPE_COMPLETED = 3
MQCMDI_QSG_DISP_COMPLETED = 4
MQCMDI_COMMAND_ACCEPTED = 5
MQCMDI_CLUSTER_REQUEST_QUEUED = 6
MQCMDI_CHANNEL_INIT_STARTED = 7
MQCMDI_RECOVER_STARTED = 11
MQCMDI_BACKUP_STARTED = 12
MQCMDI_RECOVER_COMPLETED = 13
MQCMDI_SEC_TIMER_ZERO = 14
MQCMDI_REFRESH_CONFIGURATION = 16
MQCMDI_SEC_SIGNOFF_ERROR = 17
MQCMDI_IMS_BRIDGE_SUSPENDED = 18
MQCMDI_DB2_SUSPENDED = 19
MQCMDI_DB2_OBSOLETE_MSGS = 20
MQCMDI_SEC_UPPERCASE = 21
MQCMDI_SEC_MIXEDCASE = 22
MQDISCONNECT_NORMAL = 0
MQDISCONNECT_IMPLICIT = 1
MQDISCONNECT_Q_MGR = 2
MQET_MQSC = 1
MQEVO_OTHER = 0
MQEVO_CONSOLE = 1
MQEVO_INIT = 2
MQEVO_MSG = 3
MQEVO_MQSET = 4
MQEVO_INTERNAL = 5
MQEVR_DISABLED = 0
MQEVR_ENABLED = 1
MQEVR_EXCEPTION = 2
MQEVR_NO_DISPLAY = 3
MQFC_YES = 1
MQFC_NO = 0
MQHSTATE_INACTIVE = 0
MQHSTATE_ACTIVE = 1
MQINBD_Q_MGR = 0
MQINBD_GROUP = 3
MQIDO_COMMIT = 1
MQIDO_BACKOUT = 2
MQMCAS_STOPPED = 0
MQMCAS_RUNNING = 3
MQMODE_FORCE = 0
MQMODE_QUIESCE = 1
MQMODE_TERMINATE = 2
MQPO_YES = 1
MQPO_NO = 0
MQPSST_ALL = 0
MQPSST_LOCAL = 1
MQPSST_PARENT = 2
MQPSST_CHILD = 3
MQPS_STATUS_INACTIVE = 0
MQPS_STATUS_STARTING = 1
MQPS_STATUS_STOPPING = 2
MQPS_STATUS_ACTIVE = 3
MQPS_STATUS_COMPAT = 4
MQPS_STATUS_ERROR = 5
MQPS_STATUS_REFUSED = 6
MQQMDT_EXPLICIT_CLUSTER_SENDER = 1
MQQMDT_AUTO_CLUSTER_SENDER = 2
MQQMDT_AUTO_EXP_CLUSTER_SENDER = 4
MQQMDT_CLUSTER_RECEIVER = 3
MQQMFAC_IMS_BRIDGE = 1
MQQMFAC_DB2 = 2
MQQMSTA_STARTING = 1
MQQMSTA_RUNNING = 2
MQQMSTA_QUIESCING = 3
MQQMT_NORMAL = 0
MQQMT_REPOSITORY = 1
MQQO_YES = 1
MQQO_NO = 0
MQQSIE_NONE = 0
MQQSIE_HIGH = 1
MQQSIE_OK = 2
MQQSOT_ALL = 1
MQQSOT_INPUT = 2
MQQSOT_OUTPUT = 3
MQQSGS_UNKNOWN = 0
MQQSGS_CREATED = 1
MQQSGS_ACTIVE = 2
MQQSGS_INACTIVE = 3
MQQSGS_FAILED = 4
MQQSGS_PENDING = 5
MQQSO_NO = 0
MQQSO_YES = 1
MQQSO_SHARED = 1
MQQSO_EXCLUSIVE = 2
MQQSUM_YES = 1
MQQSUM_NO = 0
MQRP_YES = 1
MQRP_NO = 0
MQRQ_CONN_NOT_AUTHORIZED = 1
MQRQ_OPEN_NOT_AUTHORIZED = 2
MQRQ_CLOSE_NOT_AUTHORIZED = 3
MQRQ_CMD_NOT_AUTHORIZED = 4
MQRQ_Q_MGR_STOPPING = 5
MQRQ_Q_MGR_QUIESCING = 6
MQRQ_CHANNEL_STOPPED_OK = 7
MQRQ_CHANNEL_STOPPED_ERROR = 8
MQRQ_CHANNEL_STOPPED_RETRY = 9
MQRQ_CHANNEL_STOPPED_DISABLED = 10
MQRQ_BRIDGE_STOPPED_OK = 11
MQRQ_BRIDGE_STOPPED_ERROR = 12
MQRQ_SSL_HANDSHAKE_ERROR = 13
MQRQ_SSL_CIPHER_SPEC_ERROR = 14
MQRQ_SSL_CLIENT_AUTH_ERROR = 15
MQRQ_SSL_PEER_NAME_ERROR = 16
MQRQ_SUB_NOT_AUTHORIZED = 17
MQRQ_SUB_DEST_NOT_AUTHORIZED = 18
MQRT_CONFIGURATION = 1
MQRT_EXPIRY = 2
MQRT_NSPROC = 3
MQRT_PROXYSUB = 4
MQSCO_Q_MGR = 1
MQSCO_CELL = 2
MQSECITEM_ALL = 0
MQSECITEM_MQADMIN = 1
MQSECITEM_MQNLIST = 2
MQSECITEM_MQPROC = 3
MQSECITEM_MQQUEUE = 4
MQSECITEM_MQCONN = 5
MQSECITEM_MQCMDS = 6
MQSECITEM_MXADMIN = 7
MQSECITEM_MXNLIST = 8
MQSECITEM_MXPROC = 9
MQSECITEM_MXQUEUE = 10
MQSECITEM_MXTOPIC = 11
MQSECSW_PROCESS = 1
MQSECSW_NAMELIST = 2
MQSECSW_Q = 3
MQSECSW_TOPIC = 4
MQSECSW_CONTEXT = 6
MQSECSW_ALTERNATE_USER = 7
MQSECSW_COMMAND = 8
MQSECSW_CONNECTION = 9
MQSECSW_SUBSYSTEM = 10
MQSECSW_COMMAND_RESOURCES = 11
MQSECSW_Q_MGR = 15
MQSECSW_QSG = 16
MQSECSW_OFF_FOUND = 21
MQSECSW_ON_FOUND = 22
MQSECSW_OFF_NOT_FOUND = 23
MQSECSW_ON_NOT_FOUND = 24
MQSECSW_OFF_ERROR = 25
MQSECSW_ON_OVERRIDDEN = 26
MQSECTYPE_AUTHSERV = 1
MQSECTYPE_SSL = 2
MQSECTYPE_CLASSES = 3
MQSUS_YES = 1
MQSUS_NO = 0
MQSYNCPOINT_YES = 0
MQSYNCPOINT_IFPER = 1
MQSYSP_NO = 0
MQSYSP_YES = 1
MQSYSP_EXTENDED = 2
MQSYSP_TYPE_INITIAL = 10
MQSYSP_TYPE_SET = 11
MQSYSP_TYPE_LOG_COPY = 12
MQSYSP_TYPE_LOG_STATUS = 13
MQSYSP_TYPE_ARCHIVE_TAPE = 14
MQSYSP_ALLOC_BLK = 20
MQSYSP_ALLOC_TRK = 21
MQSYSP_ALLOC_CYL = 22
MQSYSP_STATUS_BUSY = 30
MQSYSP_STATUS_PREMOUNT = 31
MQSYSP_STATUS_AVAILABLE = 32
MQSYSP_STATUS_UNKNOWN = 33
MQSYSP_STATUS_ALLOC_ARCHIVE = 34
MQSYSP_STATUS_COPYING_BSDS = 35
MQSYSP_STATUS_COPYING_LOG = 36
MQSUBTYPE_API = 1
MQSUBTYPE_ADMIN = 2
MQSUBTYPE_PROXY = 3
MQSUBTYPE_ALL = (-1)
MQSUBTYPE_USER = (-2)
MQTIME_UNIT_MINS = 0
MQTIME_UNIT_SECS = 1
MQUIDSUPP_NO = 0
MQUIDSUPP_YES = 1
MQUNDELIVERED_NORMAL = 0
MQUNDELIVERED_SAFE = 1
MQUNDELIVERED_DISCARD = 2
MQUNDELIVERED_KEEP = 3
MQUOWST_NONE = 0
MQUOWST_ACTIVE = 1
MQUOWST_PREPARED = 2
MQUOWST_UNRESOLVED = 3
MQUOWT_Q_MGR = 0
MQUOWT_CICS = 1
MQUOWT_RRS = 2
MQUOWT_IMS = 3
MQUOWT_XA = 4
MQUSAGE_PS_AVAILABLE = 0
MQUSAGE_PS_DEFINED = 1
MQUSAGE_PS_OFFLINE = 2
MQUSAGE_PS_NOT_DEFINED = 3
MQUSAGE_EXPAND_USER = 1
MQUSAGE_EXPAND_SYSTEM = 2
MQUSAGE_EXPAND_NONE = 3
MQUSAGE_DS_OLDEST_ACTIVE_UOW = 10
MQUSAGE_DS_OLDEST_PS_RECOVERY = 11
MQUSAGE_DS_OLDEST_CF_RECOVERY = 12
MQOPER_SYSTEM_FIRST = 0
MQOPER_UNKNOWN = 0
MQOPER_BROWSE = 1
MQOPER_DISCARD = 2
MQOPER_GET = 3
MQOPER_PUT = 4
MQOPER_PUT_REPLY = 5
MQOPER_PUT_REPORT = 6
MQOPER_RECEIVE = 7
MQOPER_SEND = 8
MQOPER_TRANSFORM = 9
MQOPER_PUBLISH = 10
MQOPER_EXCLUDED_PUBLISH = 11
MQOPER_DISCARDED_PUBLISH = 12
MQOPER_SYSTEM_LAST = 65535
MQOPER_APPL_FIRST = 65536
MQOPER_APPL_LAST = 999999999
MQROUTE_UNLIMITED_ACTIVITIES = 0
MQROUTE_DETAIL_LOW = 0x00000002
MQROUTE_DETAIL_MEDIUM = 0x00000008
MQROUTE_DETAIL_HIGH = 0x00000020
MQROUTE_FORWARD_ALL = 0x00000100
MQROUTE_FORWARD_IF_SUPPORTED = 0x00000200
MQROUTE_FORWARD_REJ_UNSUP_MASK = (-65536)
MQROUTE_DELIVER_YES = 0x00001000
MQROUTE_DELIVER_NO = 0x00002000
MQROUTE_DELIVER_REJ_UNSUP_MASK = (-65536)
MQROUTE_ACCUMULATE_NONE = 0x00010003
MQROUTE_ACCUMULATE_IN_MSG = 0x00010004
MQROUTE_ACCUMULATE_AND_REPLY = 0x00010005
MQDELO_NONE = 0x00000000
MQDELO_LOCAL = 0x00000004
MQPUBO_NONE = 0x00000000
MQPUBO_CORREL_ID_AS_IDENTITY = 0x00000001
MQPUBO_RETAIN_PUBLICATION = 0x00000002
MQPUBO_OTHER_SUBSCRIBERS_ONLY = 0x00000004
MQPUBO_NO_REGISTRATION = 0x00000008
MQPUBO_IS_RETAINED_PUBLICATION = 0x00000010
MQREGO_NONE = 0x00000000
MQREGO_CORREL_ID_AS_IDENTITY = 0x00000001
MQREGO_ANONYMOUS = 0x00000002
MQREGO_LOCAL = 0x00000004
MQREGO_DIRECT_REQUESTS = 0x00000008
MQREGO_NEW_PUBLICATIONS_ONLY = 0x00000010
MQREGO_PUBLISH_ON_REQUEST_ONLY = 0x00000020
MQREGO_DEREGISTER_ALL = 0x00000040
MQREGO_INCLUDE_STREAM_NAME = 0x00000080
MQREGO_INFORM_IF_RETAINED = 0x00000100
MQREGO_DUPLICATES_OK = 0x00000200
MQREGO_NON_PERSISTENT = 0x00000400
MQREGO_PERSISTENT = 0x00000800
MQREGO_PERSISTENT_AS_PUBLISH = 0x00001000
MQREGO_PERSISTENT_AS_Q = 0x00002000
MQREGO_ADD_NAME = 0x00004000
MQREGO_NO_ALTERATION = 0x00008000
MQREGO_FULL_RESPONSE = 0x00010000
MQREGO_JOIN_SHARED = 0x00020000
MQREGO_JOIN_EXCLUSIVE = 0x00040000
MQREGO_LEAVE_ONLY = 0x00080000
MQREGO_VARIABLE_USER_ID = 0x00100000
MQREGO_LOCKED = 0x00200000
MQUA_FIRST = 65536
MQUA_LAST = 999999999
MQCFGR_DEFAULT = MQCFT_GROUP,\
                        MQCFGR_STRUC_LENGTH,\
                        0,\
                        0
MQCFIF_DEFAULT = MQCFT_INTEGER_FILTER,\
                        MQCFIF_STRUC_LENGTH,\
                        0,\
                        0,\
                        0
MQCFIN_DEFAULT = MQCFT_INTEGER,\
                        MQCFIN_STRUC_LENGTH,\
                        0,\
                        0
MQCFIN64_DEFAULT = MQCFT_INTEGER64,\
                        MQCFIN64_STRUC_LENGTH,\
                        0,\
                        0,\
                        0
